@@ -11,8 +11,8 @@ class NamingAnalyser(Analyser):
     CONSTANT_SNAKE_CASE = re.compile(r"(([A-Z_][A-Z0-9_]*)|(__.*__))$")
     HUNGARIAN_NOTATION = re.compile(r"(?<![^\W_\d])"
                                     r"(str|string|int|list|lst|dict|dictionary|"
-                                    r"tup|tuple|float|func|function|method|"
-                                    r"char|character)"
+                                    r"tup|tuple|float|func|function|method|chr|"
+                                    r"character)"
                                     r"(?![^\W_\d])")
 
     @register_check(error_format="{}:{}: Non snake-case variable '{}':\n\t{}")
@@ -68,7 +68,6 @@ class NamingAnalyser(Analyser):
     def check_potential_bad_variable_names(self):
         """Checks for potential bad naming, i.e. names with 1-2 characters """
         results: list[tuple[str, int, str, str]] = []
-        whitelist = ['_']
         for filename, attr in self._sources.items():
             for node in attr.tree.pre_order():
                 if not isinstance(node, AssignName):
@@ -82,9 +81,6 @@ class NamingAnalyser(Analyser):
                 if len(node.name) >= 3:
                     continue
 
-                if node.name in whitelist:
-                    continue
-
                 results.append((filename, node.lineno, node.name,
                                 node.parent.as_string().splitlines()[0]))
         return results
@@ -123,14 +119,11 @@ class NamingAnalyser(Analyser):
                                  "name '{}':\n\t{}")
     def check_hungarian_notation_method(self):
         """Checks for hungarian notation function and method naming """
-        whitelist = ["__str__"]
         results: list[tuple[str, int, str, str]] = []
         for filename, attr in self._sources.items():
             for node in attr.tree.pre_order():
                 if not isinstance(node, FunctionDef):
                     continue
-                if node.name in whitelist:
-                    continue
                 if not self.HUNGARIAN_NOTATION.search(node.name):
                     continue
                 results.append((filename, node.lineno, node.name,
